Documentation
¶
Overview ¶
FILE GENERATED AUTOMATICALLY FROM "xf86dri.xml"
Index ¶
- Constants
- func AuthConnectionUnchecked(c *xgb.XConn, Screen uint32, Magic uint32) error
- func CloseConnection(c *xgb.XConn, Screen uint32) error
- func CloseConnectionUnchecked(c *xgb.XConn, Screen uint32) error
- func CreateContextUnchecked(c *xgb.XConn, Screen uint32, Visual uint32, Context uint32) error
- func CreateDrawableUnchecked(c *xgb.XConn, Screen uint32, Drawable uint32) error
- func DestroyContext(c *xgb.XConn, Screen uint32, Context uint32) error
- func DestroyContextUnchecked(c *xgb.XConn, Screen uint32, Context uint32) error
- func DestroyDrawable(c *xgb.XConn, Screen uint32, Drawable uint32) error
- func DestroyDrawableUnchecked(c *xgb.XConn, Screen uint32, Drawable uint32) error
- func DrmClipRectListBytes(buf []byte, list []DrmClipRect) int
- func DrmClipRectRead(buf []byte, v *DrmClipRect) int
- func DrmClipRectReadList(buf []byte, dest []DrmClipRect) int
- func GetClientDriverNameUnchecked(c *xgb.XConn, Screen uint32) error
- func GetDeviceInfoUnchecked(c *xgb.XConn, Screen uint32) error
- func GetDrawableInfoUnchecked(c *xgb.XConn, Screen uint32, Drawable uint32) error
- func OpenConnectionUnchecked(c *xgb.XConn, Screen uint32) error
- func QueryDirectRenderingCapableUnchecked(c *xgb.XConn, Screen uint32) error
- func QueryVersionUnchecked(c *xgb.XConn) error
- func Register(xconn *xgb.XConn) error
- type AuthConnectionReply
- type CreateContextReply
- type CreateDrawableReply
- type DrmClipRect
- type GetClientDriverNameReply
- type GetDeviceInfoReply
- type GetDrawableInfoReply
- type OpenConnectionReply
- type QueryDirectRenderingCapableReply
- type QueryVersionReply
Constants ¶
const ( // ExtName is the user-friendly name string of this X extension. ExtName = "XF86Dri" // ExtXName is the name string this extension is known by to the X server. ExtXName = "XFree86-DRI" )
Variables ¶
This section is empty.
Functions ¶
func AuthConnectionUnchecked ¶
AuthConnectionUnchecked sends an unchecked request.
func CloseConnection ¶
CloseConnection sends a checked request.
func CloseConnectionUnchecked ¶ added in v1.1.0
CloseConnectionUnchecked sends an unchecked request.
func CreateContextUnchecked ¶
CreateContextUnchecked sends an unchecked request.
func CreateDrawableUnchecked ¶
CreateDrawableUnchecked sends an unchecked request.
func DestroyContext ¶
DestroyContext sends a checked request.
func DestroyContextUnchecked ¶ added in v1.1.0
DestroyContextUnchecked sends an unchecked request.
func DestroyDrawable ¶
DestroyDrawable sends a checked request.
func DestroyDrawableUnchecked ¶ added in v1.1.0
DestroyDrawableUnchecked sends an unchecked request.
func DrmClipRectListBytes ¶
func DrmClipRectListBytes(buf []byte, list []DrmClipRect) int
DrmClipRectListBytes writes a list of DrmClipRect values to a byte slice.
func DrmClipRectRead ¶
func DrmClipRectRead(buf []byte, v *DrmClipRect) int
DrmClipRectRead reads a byte slice into a DrmClipRect value.
func DrmClipRectReadList ¶
func DrmClipRectReadList(buf []byte, dest []DrmClipRect) int
DrmClipRectReadList reads a byte slice into a list of DrmClipRect values.
func GetClientDriverNameUnchecked ¶
GetClientDriverNameUnchecked sends an unchecked request.
func GetDeviceInfoUnchecked ¶
GetDeviceInfoUnchecked sends an unchecked request.
func GetDrawableInfoUnchecked ¶
GetDrawableInfoUnchecked sends an unchecked request.
func OpenConnectionUnchecked ¶
OpenConnectionUnchecked sends an unchecked request.
func QueryDirectRenderingCapableUnchecked ¶
QueryDirectRenderingCapableUnchecked sends an unchecked request.
func QueryVersionUnchecked ¶
QueryVersionUnchecked sends an unchecked request.
Types ¶
type AuthConnectionReply ¶
type AuthConnectionReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
Authenticated uint32
}
AuthConnectionReply represents the data returned from a AuthConnection request.
func AuthConnection ¶
AuthConnection sends a checked request.
func (*AuthConnectionReply) Unmarshal ¶ added in v1.1.0
func (v *AuthConnectionReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a AuthConnectionReply value.
type CreateContextReply ¶
type CreateContextReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
HwContext uint32
}
CreateContextReply represents the data returned from a CreateContext request.
func CreateContext ¶
func CreateContext(c *xgb.XConn, Screen uint32, Visual uint32, Context uint32) (CreateContextReply, error)
CreateContext sends a checked request.
func (*CreateContextReply) Unmarshal ¶ added in v1.1.0
func (v *CreateContextReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a CreateContextReply value.
type CreateDrawableReply ¶
type CreateDrawableReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
HwDrawableHandle uint32
}
CreateDrawableReply represents the data returned from a CreateDrawable request.
func CreateDrawable ¶
CreateDrawable sends a checked request.
func (*CreateDrawableReply) Unmarshal ¶ added in v1.1.0
func (v *CreateDrawableReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a CreateDrawableReply value.
type DrmClipRect ¶
func (DrmClipRect) Bytes ¶
func (v DrmClipRect) Bytes() []byte
Bytes writes a DrmClipRect value to a byte slice.
type GetClientDriverNameReply ¶
type GetClientDriverNameReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
ClientDriverMajorVersion uint32
ClientDriverMinorVersion uint32
ClientDriverPatchVersion uint32
ClientDriverNameLen uint32
// padding: 8 bytes
ClientDriverName string // size: internal.Pad4((int(ClientDriverNameLen) * 1))
}
GetClientDriverNameReply represents the data returned from a GetClientDriverName request.
func GetClientDriverName ¶
func GetClientDriverName(c *xgb.XConn, Screen uint32) (GetClientDriverNameReply, error)
GetClientDriverName sends a checked request.
func (*GetClientDriverNameReply) Unmarshal ¶ added in v1.1.0
func (v *GetClientDriverNameReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a GetClientDriverNameReply value.
type GetDeviceInfoReply ¶
type GetDeviceInfoReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
FramebufferHandleLow uint32
FramebufferHandleHigh uint32
FramebufferOriginOffset uint32
FramebufferSize uint32
FramebufferStride uint32
DevicePrivateSize uint32
DevicePrivate []uint32 // size: internal.Pad4((int(DevicePrivateSize) * 4))
}
GetDeviceInfoReply represents the data returned from a GetDeviceInfo request.
func GetDeviceInfo ¶
func GetDeviceInfo(c *xgb.XConn, Screen uint32) (GetDeviceInfoReply, error)
GetDeviceInfo sends a checked request.
func (*GetDeviceInfoReply) Unmarshal ¶ added in v1.1.0
func (v *GetDeviceInfoReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a GetDeviceInfoReply value.
type GetDrawableInfoReply ¶
type GetDrawableInfoReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
DrawableTableIndex uint32
DrawableTableStamp uint32
DrawableOriginX int16
DrawableOriginY int16
DrawableSizeW int16
DrawableSizeH int16
NumClipRects uint32
BackX int16
BackY int16
NumBackClipRects uint32
ClipRects []DrmClipRect // size: internal.Pad4((int(NumClipRects) * 8))
// alignment gap to multiple of 4
BackClipRects []DrmClipRect // size: internal.Pad4((int(NumBackClipRects) * 8))
}
GetDrawableInfoReply represents the data returned from a GetDrawableInfo request.
func GetDrawableInfo ¶
GetDrawableInfo sends a checked request.
func (*GetDrawableInfoReply) Unmarshal ¶ added in v1.1.0
func (v *GetDrawableInfoReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a GetDrawableInfoReply value.
type OpenConnectionReply ¶
type OpenConnectionReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
SareaHandleLow uint32
SareaHandleHigh uint32
BusIdLen uint32
// padding: 12 bytes
BusId string // size: internal.Pad4((int(BusIdLen) * 1))
}
OpenConnectionReply represents the data returned from a OpenConnection request.
func OpenConnection ¶
func OpenConnection(c *xgb.XConn, Screen uint32) (OpenConnectionReply, error)
OpenConnection sends a checked request.
func (*OpenConnectionReply) Unmarshal ¶ added in v1.1.0
func (v *OpenConnectionReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a OpenConnectionReply value.
type QueryDirectRenderingCapableReply ¶
type QueryDirectRenderingCapableReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
IsCapable bool
}
QueryDirectRenderingCapableReply represents the data returned from a QueryDirectRenderingCapable request.
func QueryDirectRenderingCapable ¶
func QueryDirectRenderingCapable(c *xgb.XConn, Screen uint32) (QueryDirectRenderingCapableReply, error)
QueryDirectRenderingCapable sends a checked request.
func (*QueryDirectRenderingCapableReply) Unmarshal ¶ added in v1.1.0
func (v *QueryDirectRenderingCapableReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a QueryDirectRenderingCapableReply value.
type QueryVersionReply ¶
type QueryVersionReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
DriMajorVersion uint16
DriMinorVersion uint16
DriMinorPatch uint32
}
QueryVersionReply represents the data returned from a QueryVersion request.
func QueryVersion ¶
func QueryVersion(c *xgb.XConn) (QueryVersionReply, error)
QueryVersion sends a checked request.
func (*QueryVersionReply) Unmarshal ¶ added in v1.1.0
func (v *QueryVersionReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a QueryVersionReply value.