Documentation
¶
Overview ¶
FILE GENERATED AUTOMATICALLY FROM "xvmc.xml"
Index ¶
- Constants
- func CreateContextUnchecked(c *xgb.XConn, ContextId Context, PortId xv.Port, SurfaceId Surface, ...) error
- func CreateSubpictureUnchecked(c *xgb.XConn, SubpictureId Subpicture, Context Context, XvimageId uint32, ...) error
- func CreateSurfaceUnchecked(c *xgb.XConn, SurfaceId Surface, ContextId Context) error
- func DestroyContext(c *xgb.XConn, ContextId Context) error
- func DestroyContextUnchecked(c *xgb.XConn, ContextId Context) error
- func DestroySubpicture(c *xgb.XConn, SubpictureId Subpicture) error
- func DestroySubpictureUnchecked(c *xgb.XConn, SubpictureId Subpicture) error
- func DestroySurface(c *xgb.XConn, SurfaceId Surface) error
- func DestroySurfaceUnchecked(c *xgb.XConn, SurfaceId Surface) error
- func ListSubpictureTypesUnchecked(c *xgb.XConn, PortId xv.Port, SurfaceId Surface) error
- func ListSurfaceTypesUnchecked(c *xgb.XConn, PortId xv.Port) error
- func QueryVersionUnchecked(c *xgb.XConn) error
- func Register(xconn *xgb.XConn) error
- func SurfaceInfoListBytes(buf []byte, list []SurfaceInfo) int
- func SurfaceInfoRead(buf []byte, v *SurfaceInfo) int
- func SurfaceInfoReadList(buf []byte, dest []SurfaceInfo) int
- type Context
- type CreateContextReply
- type CreateSubpictureReply
- type CreateSurfaceReply
- type ListSubpictureTypesReply
- type ListSurfaceTypesReply
- type QueryVersionReply
- type Subpicture
- type Surface
- type SurfaceInfo
Constants ¶
const ( // ExtName is the user-friendly name string of this X extension. ExtName = "XvMC" // ExtXName is the name string this extension is known by to the X server. ExtXName = "XVideo-MotionCompensation" )
Variables ¶
This section is empty.
Functions ¶
func CreateContextUnchecked ¶
func CreateContextUnchecked(c *xgb.XConn, ContextId Context, PortId xv.Port, SurfaceId Surface, Width uint16, Height uint16, Flags uint32) error
CreateContextUnchecked sends an unchecked request.
func CreateSubpictureUnchecked ¶
func CreateSubpictureUnchecked(c *xgb.XConn, SubpictureId Subpicture, Context Context, XvimageId uint32, Width uint16, Height uint16) error
CreateSubpictureUnchecked sends an unchecked request.
func CreateSurfaceUnchecked ¶
CreateSurfaceUnchecked sends an unchecked request.
func DestroyContext ¶
DestroyContext sends a checked request.
func DestroyContextUnchecked ¶ added in v1.1.0
DestroyContextUnchecked sends an unchecked request.
func DestroySubpicture ¶
func DestroySubpicture(c *xgb.XConn, SubpictureId Subpicture) error
DestroySubpicture sends a checked request.
func DestroySubpictureUnchecked ¶ added in v1.1.0
func DestroySubpictureUnchecked(c *xgb.XConn, SubpictureId Subpicture) error
DestroySubpictureUnchecked sends an unchecked request.
func DestroySurface ¶
DestroySurface sends a checked request.
func DestroySurfaceUnchecked ¶ added in v1.1.0
DestroySurfaceUnchecked sends an unchecked request.
func ListSubpictureTypesUnchecked ¶
ListSubpictureTypesUnchecked sends an unchecked request.
func ListSurfaceTypesUnchecked ¶
ListSurfaceTypesUnchecked sends an unchecked request.
func QueryVersionUnchecked ¶
QueryVersionUnchecked sends an unchecked request.
func Register ¶ added in v1.1.0
Register will query the X server for XvMC extension support, and register relevant extension unmarshalers with the XConn.
func SurfaceInfoListBytes ¶
func SurfaceInfoListBytes(buf []byte, list []SurfaceInfo) int
SurfaceInfoListBytes writes a list of SurfaceInfo values to a byte slice.
func SurfaceInfoRead ¶
func SurfaceInfoRead(buf []byte, v *SurfaceInfo) int
SurfaceInfoRead reads a byte slice into a SurfaceInfo value.
func SurfaceInfoReadList ¶
func SurfaceInfoReadList(buf []byte, dest []SurfaceInfo) int
SurfaceInfoReadList reads a byte slice into a list of SurfaceInfo values.
Types ¶
type CreateContextReply ¶
type CreateContextReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
WidthActual uint16
HeightActual uint16
FlagsReturn uint32
// padding: 20 bytes
PrivData []uint32 // size: internal.Pad4((int(Length) * 4))
}
CreateContextReply represents the data returned from a CreateContext request.
func CreateContext ¶
func CreateContext(c *xgb.XConn, ContextId Context, PortId xv.Port, SurfaceId Surface, Width uint16, Height uint16, Flags uint32) (CreateContextReply, error)
CreateContext sends a checked request.
func (*CreateContextReply) Unmarshal ¶ added in v1.1.0
func (v *CreateContextReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a CreateContextReply value.
type CreateSubpictureReply ¶
type CreateSubpictureReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
WidthActual uint16
HeightActual uint16
NumPaletteEntries uint16
EntryBytes uint16
ComponentOrder []byte // size: 4
// padding: 12 bytes
PrivData []uint32 // size: internal.Pad4((int(Length) * 4))
}
CreateSubpictureReply represents the data returned from a CreateSubpicture request.
func CreateSubpicture ¶
func CreateSubpicture(c *xgb.XConn, SubpictureId Subpicture, Context Context, XvimageId uint32, Width uint16, Height uint16) (CreateSubpictureReply, error)
CreateSubpicture sends a checked request.
func (*CreateSubpictureReply) Unmarshal ¶ added in v1.1.0
func (v *CreateSubpictureReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a CreateSubpictureReply value.
type CreateSurfaceReply ¶
type CreateSurfaceReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
// padding: 24 bytes
PrivData []uint32 // size: internal.Pad4((int(Length) * 4))
}
CreateSurfaceReply represents the data returned from a CreateSurface request.
func CreateSurface ¶
CreateSurface sends a checked request.
func (*CreateSurfaceReply) Unmarshal ¶ added in v1.1.0
func (v *CreateSurfaceReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a CreateSurfaceReply value.
type ListSubpictureTypesReply ¶
type ListSubpictureTypesReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
Num uint32
// padding: 20 bytes
Types []xv.ImageFormatInfo // size: xv.ImageFormatInfoListSize(Types)
}
ListSubpictureTypesReply represents the data returned from a ListSubpictureTypes request.
func ListSubpictureTypes ¶
func ListSubpictureTypes(c *xgb.XConn, PortId xv.Port, SurfaceId Surface) (ListSubpictureTypesReply, error)
ListSubpictureTypes sends a checked request.
func (*ListSubpictureTypesReply) Unmarshal ¶ added in v1.1.0
func (v *ListSubpictureTypesReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a ListSubpictureTypesReply value.
type ListSurfaceTypesReply ¶
type ListSurfaceTypesReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
Num uint32
// padding: 20 bytes
Surfaces []SurfaceInfo // size: internal.Pad4((int(Num) * 24))
}
ListSurfaceTypesReply represents the data returned from a ListSurfaceTypes request.
func ListSurfaceTypes ¶
ListSurfaceTypes sends a checked request.
func (*ListSurfaceTypesReply) Unmarshal ¶ added in v1.1.0
func (v *ListSurfaceTypesReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a ListSurfaceTypesReply value.
type QueryVersionReply ¶
type QueryVersionReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
Major uint32
Minor uint32
}
QueryVersionReply represents the data returned from a QueryVersion request.
func QueryVersion ¶
func QueryVersion(c *xgb.XConn) (QueryVersionReply, error)
QueryVersion sends a checked request.
func (*QueryVersionReply) Unmarshal ¶ added in v1.1.0
func (v *QueryVersionReply) Unmarshal(buf []byte) error
Unmarshal reads a byte slice into a QueryVersionReply value.
type Subpicture ¶
type Subpicture uint32
func NewSubpictureID ¶ added in v1.1.0
func NewSubpictureID(c *xgb.XConn) Subpicture
type SurfaceInfo ¶
type SurfaceInfo struct {
Id Surface
ChromaFormat uint16
Pad0 uint16
MaxWidth uint16
MaxHeight uint16
SubpictureMaxWidth uint16
SubpictureMaxHeight uint16
McType uint32
Flags uint32
}
func (SurfaceInfo) Bytes ¶
func (v SurfaceInfo) Bytes() []byte
Bytes writes a SurfaceInfo value to a byte slice.